'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var Vue = _interopDefault(require('vue'));

var originalContent = undefined;

function selectPattern(word, liveHighlighting) {
  if ( liveHighlighting === void 0 ) liveHighlighting = false;

  var result = "";
  if (!liveHighlighting) {
    result = "\\b(" + word + ")\\b";
  } else {
    result = "(" + word + ")";
  }
  return result;
}

function highlight(content, word, patternSelected) {
  var spanStart = "<span style='padding:0px 5px; background-color:#009688; color:white'>";
  var spanEnd = "</span>";
  var result = content;
  if (word != "") {
    var regex = new RegExp(patternSelected, "g");
    result = content.replace(regex, spanStart + "$&" + spanEnd);
  }
  return result;
}

var vueHighlighter = {
  bind: function bind(el, binding, vnode) {
    originalContent = el.innerHTML;
    var pattern = "";
    var word = "";
    if (binding.value.word != undefined) {
      word = binding.value.word;
    }
    if (binding.value.live != undefined) {
      pattern = selectPattern(word, binding.value.live);
    }
    el.innerHTML = highlight(originalContent, word, pattern);
  },
  update: function update(el, binding, vnode, oldVnode) {
    var pattern = "";
    if (binding.value.live) {
      pattern = selectPattern(binding.value.word, binding.value.word);
      el.innerHTML = highlight(el.textContent, binding.value.word, pattern);
    } else {
      pattern = selectPattern(binding.value.word, binding.value.live);
      el.innerHTML = highlight(originalContent, binding.value.word, pattern);
    }
  },
  unbind: function unbind(el, binding, vnode) {
    el.innerHTML = originalContent;
  }
};

Vue.directive("highlight", vueHighlighter);

module.exports = vueHighlighter;
